@@ -293,7 +293,7 @@ class Generator(object):
             # https://discussions.apple.com/thread/251041261
 
             # (probably not duplicated.)
-            anchor = anchor.replace('%', '-')
+            anchor = anchor.replace('%25', '-').replace('%', '-')
             return anchor
 
         for anchor in soup.find_all(id=True):
@@ -301,17 +301,19 @@ class Generator(object):
         for link in soup.find_all('a', href=True):
             link['href'] = normalize_anchor_chars(link['href'])
 
-        if not self._options.debug_html:
+        if not (self._options.debug_html or self._options.show_anchors or
+                self._options.strict or self._options.verbose):
             return
 
         from urllib.parse import urlparse
 
         anchors = set(map(lambda el: '#' + el['id'], soup.find_all(id=True)))
 
-        '''
-        from pprint import pprint as pp
-        pp(anchors)
-        '''
+        if not (self._options.strict or self._options.debug_html):
+            self.logger.info('Anchor points provided:')
+            for anchor in sorted(anchors):
+                self.logger.info(f'| {anchor}')
+            return
 
         missing = set()
         for el in soup.find_all('a', href=True):
@@ -329,9 +331,12 @@ class Generator(object):
             self.logger.error(f'Missing {len(missing)} link(s):')
             for link in sorted(missing):
                 self.logger.warning(f'  | {link}')
-            self.logger.info('  | --- found anchors:')
-            for anchor in sorted(anchors):
-                self.logger.info(f'  | {anchor}')
+            if (self._options.show_anchors or
+                self._options.verbose or
+                    self._options.debug_html):
+                self.logger.info('  | --- found anchors:')
+                for anchor in sorted(anchors):
+                    self.logger.info(f'  | {anchor}')
 
     # -------------------------------------------------------------
 
